@@ -20,6 +20,7 @@ KNOWN ISSUES:
      positives or false negatives.
 """
 
+import six
 from django.core.management.base import BaseCommand
 from django.core.management import sql as _sql
 from django.core.management import CommandError
@@ -104,7 +105,7 @@ class SQLDiff(object):
     SQL_INDEX_MISSING_IN_DB = lambda self, style, qn, args: "%s %s\n\t%s %s (%s%s);" % (style.SQL_KEYWORD('CREATE INDEX'), style.SQL_TABLE(qn("%s" % '_'.join(a for a in args[0:3] if a))), style.SQL_KEYWORD('ON'), style.SQL_TABLE(qn(args[0])), style.SQL_FIELD(qn(args[1])), style.SQL_KEYWORD(args[3]))
     # FIXME: need to lookup index name instead of just appending _idx to table + fieldname
     SQL_INDEX_MISSING_IN_MODEL = lambda self, style, qn, args: "%s %s;" % (style.SQL_KEYWORD('DROP INDEX'), style.SQL_TABLE(qn("%s" % '_'.join(a for a in args[0:3] if a))))
-    SQL_UNIQUE_MISSING_IN_DB = lambda self, style, qn, args: "%s %s\n\t%s %s (%s);" % (style.SQL_KEYWORD('ALTER TABLE'), style.SQL_TABLE(qn(args[0])), style.SQL_KEYWORD('ADD COLUMN'), style.SQL_KEYWORD('UNIQUE'), style.SQL_FIELD(qn(args[1])))
+    SQL_UNIQUE_MISSING_IN_DB = lambda self, style, qn, args: "%s %s\n\t%s %s (%s);" % (style.SQL_KEYWORD('ALTER TABLE'), style.SQL_TABLE(qn(args[0])), style.SQL_KEYWORD('ADD'), style.SQL_KEYWORD('UNIQUE'), style.SQL_FIELD(qn(args[1])))
     # FIXME: need to lookup unique constraint name instead of appending _key to table + fieldname
     SQL_UNIQUE_MISSING_IN_MODEL = lambda self, style, qn, args: "%s %s\n\t%s %s %s;" % (style.SQL_KEYWORD('ALTER TABLE'), style.SQL_TABLE(qn(args[0])), style.SQL_KEYWORD('DROP'), style.SQL_KEYWORD('CONSTRAINT'), style.SQL_TABLE(qn("%s_key" % ('_'.join(args[:2])))))
     SQL_FIELD_TYPE_DIFFER = lambda self, style, qn, args: "%s %s\n\t%s %s %s;" % (style.SQL_KEYWORD('ALTER TABLE'), style.SQL_TABLE(qn(args[0])), style.SQL_KEYWORD("MODIFY"), style.SQL_FIELD(qn(args[1])), style.SQL_COLTYPE(args[2]))
@@ -234,7 +235,7 @@ class SQLDiff(object):
 
         if description[6]:
             kwargs['blank'] = True
-            if not reverse_type in ('TextField', 'CharField'):
+            if reverse_type not in ('TextField', 'CharField'):
                 kwargs['null'] = True
 
         if '.' in reverse_type:
@@ -274,7 +275,7 @@ class SQLDiff(object):
         # TODO: Postgresql does not list unique_togethers in table_indexes
         #       MySQL does
         fields = dict([(field.db_column or field.name, field.unique) for field in all_local_fields(meta)])
-        for att_name, att_opts in table_indexes.iteritems():
+        for att_name, att_opts in six.iteritems(table_indexes):
             if att_opts['unique'] and att_name in fields and not fields[att_name]:
                 if att_name in flatten(meta.unique_together):
                     continue
@@ -284,7 +285,7 @@ class SQLDiff(object):
         for field in all_local_fields(meta):
             if field.db_index:
                 attname = field.db_column or field.attname
-                if not attname in table_indexes:
+                if attname not in table_indexes:
                     self.add_difference('index-missing-in-db', table_name, attname, '', '')
                     db_type = field.db_type(connection=connection)
                     if db_type.startswith('varchar'):
@@ -294,7 +295,7 @@ class SQLDiff(object):
 
     def find_index_missing_in_model(self, meta, table_indexes, table_name):
         fields = dict([(field.name, field) for field in all_local_fields(meta)])
-        for att_name, att_opts in table_indexes.iteritems():
+        for att_name, att_opts in six.iteritems(table_indexes):
             if att_name in fields:
                 field = fields[att_name]
                 if field.db_index:
@@ -317,7 +318,7 @@ class SQLDiff(object):
 
     def find_field_missing_in_db(self, fieldmap, table_description, table_name):
         db_fields = [row[0] for row in table_description]
-        for field_name, field in fieldmap.iteritems():
+        for field_name, field in six.iteritems(fieldmap):
             if field_name not in db_fields:
                 field_output = []
                 if field.rel:
@@ -392,8 +393,7 @@ class SQLDiff(object):
                 # Marker indicating start of difference scan for this table_name
                 self.add_app_model_marker(app_label, app_model.__name__)
 
-            #if not table_name in self.django_tables:
-            if not table_name in self.db_tables:
+            if table_name not in self.db_tables:
                 # Table is missing from database
                 self.add_difference('table-missing-in-db', table_name)
                 continue
@@ -707,10 +707,6 @@ to check/debug ur models compared to the real database tables and columns."""
     args = '<appname appname ...>'
 
     def handle(self, *app_labels, **options):
-        from django import VERSION
-        if VERSION[:2] < (1, 0):
-            raise CommandError("SQLDiff only support Django 1.0 or higher!")
-
         from django.db import models
         from django.conf import settings
 
